.. fitsblender documentation master file, created by
   sphinx-quickstart on Wed Sep 15 11:27:12 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fitsblender's documentation!
=======================================

.. automodule:: fitsblender
   :members: fitsblender


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

